@@ -19,7 +19,8 @@ test_that("vectors", {
   expect_equal(retype(as.character(c("1", "2,0", NA))), as.character(c("1", "2,0", NA)))
   expect_equal(retype(as.character(c("1", "2.5", NA))), as.numeric(c(1, 2.5, NA)))
   expect_equal(retype(as.character(c("2018-01-25", "2018-01-27", NA))), as.Date(c("2018-01-25", "2018-01-27", NA)))
-  expect_equal(retype(as.character(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA))), as.Date(c("2018-10-10", "2018-10-10", NA)))
+  expect_equal(retype(as.character(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA))), 
+               as.POSIXct(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA)))
   expect_equal(retype(as.character(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:25 CEST", NA))), as.POSIXct(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:25 CEST", NA)))
 
   expect_equal(retype(as.factor(c("a"))), as.character(c("a")))
@@ -29,7 +30,7 @@ test_that("vectors", {
   expect_equal(retype(as.factor(c("1", "2.5", NA))), as.numeric(c(1, 2.5, NA)))
   expect_equal(retype(as.factor(c("1", "2,5", NA))), as.character(c("1", "2,5", NA)))
   expect_equal(retype(as.factor(c("2018-01-25", "2018-01-27", NA))), as.Date(c("2018-01-25", "2018-01-27", NA)))
-  expect_equal(retype(as.factor(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA))), as.Date(c("2018-10-10", "2018-10-10", NA)))
+  expect_equal(retype(as.factor(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA))), as.POSIXct(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:20 CEST", NA)))
   expect_equal(retype(as.factor(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:25 CEST", NA))), as.POSIXct(c("2018-10-10 11:30:20 CEST", "2018-10-10 11:30:25 CEST", NA)))
 
   expect_equal(retype(list("a", "b")), list("a", "b"))
@@ -87,19 +88,19 @@ test_that("data.frame", {
                                       n = as.character(c("a", "b", NA, "q", NA)),
 
                                       o = as.Date(c("2018-02-01", "2018-04-15", NA, NA, "2016-05-15")),
-                                      p = as.Date(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
+                                      p = as.POSIXct(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
                                       q = as.POSIXct(c("2018-02-01 01:00", "2018-04-15 16:56", NA, NA, "2016-05-15 17:10")),
                                       r = as.POSIXct(c("2018-02-01 01:00 CEST", "2018-04-15 16:56 CEST", NA, NA, "2016-05-15 17:10 CEST")),
                                       s = as.POSIXct(c("2018-02-01 01:00 CEST", "2018-04-15 16:56 CEST", NA, NA, "2016-05-15 17:10 CEST")),
 
-                                      t = as.Date(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
+                                      t = as.POSIXct(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
                                       u = as.POSIXct(c("2018-02-01 01:00 CEST", "2018-04-15 16:56 CEST", NA, NA, "2016-05-15 17:10 CEST")),
 
                                       v = as.integer(c(1, 1, NA, 0, 1)),
                                       w = as.numeric(c(1, 1.78, NA, NaN, 1))))
 
   expect_equal(retype(df, p), df %>% mutate_at(vars(p), ~retype(.)))
-  expect_equal(retype(df, p), df %>% mutate_at(vars(p), ~as.Date(.)))
+  expect_equal(retype(df, p), df %>% mutate_at(vars(p), ~as.POSIXct(.)))
   expect_equal(retype(df, -t), tibble(a = as.numeric(c(1, Inf, 3, 2, 4)),
                                           b = as.integer(c(1, 7, 3, 2, 4)),
                                           c = as.integer(c(1, NA, 3, 2, 4)),
@@ -119,7 +120,7 @@ test_that("data.frame", {
                                           n = as.character(c("a", "b", NA, "q", NA)),
 
                                           o = as.Date(c("2018-02-01", "2018-04-15", NA, NA, "2016-05-15")),
-                                          p = as.Date(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
+                                          p = as.POSIXct(c("2018-02-01 01:00", "2018-04-15 01:00", NA, NA, "2016-05-15 01:00")),
                                           q = as.POSIXct(c("2018-02-01 01:00", "2018-04-15 16:56", NA, NA, "2016-05-15 17:10")),
                                           r = as.POSIXct(c("2018-02-01 01:00 CEST", "2018-04-15 16:56 CEST", NA, NA, "2016-05-15 17:10 CEST")),
                                           s = as.POSIXct(c("2018-02-01 01:00 CEST", "2018-04-15 16:56 CEST", NA, NA, "2016-05-15 17:10 CEST")),
